@@ -851,7 +851,7 @@ class NestedModelViewSet(QueryArgumentsMixin, viewsets.ModelViewSet):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
         enable_filter_schema = getattr(self, "enable_filter_schema", False)  # showing filters in swagger or not.
-        if self.queryset:
+        if self.queryset is not None:
             self.filterset_class = GenericFilterSet(self.queryset.model, enable_filter_schema).FilterSet
         else:
             self.filterset_class = None
